@@ -42,10 +42,8 @@ pub trait Emulator {
         self.emulate_instruction(self.get_current_ip(), true)
     }
 
-    /// Returns the number of instructions the emulator has decoded.
-    ///
-    /// Every call to emulate an instruction is counted, even if the instruction doesn't retire.
-    fn get_decoded_instruction_count(&self) -> usize;
+    /// Returns the number of emulated instructions, regardless of whether they have been committed.
+    fn get_instruction_count(&self) -> usize;
     /// Returns the current instruction pointer address.
     fn get_current_ip(&self) -> usize;
     /// Returns the output the emulated program has written to stdout.
