@@ -1,6 +1,6 @@
 // Filename: lib.rs
-// Version:	 0.8
-// Date:	 09-07-2021 (DD-MM-YYYY)
+// Version:	 0.9
+// Date:	 14-11-2021 (DD-MM-YYYY)
 // Library:  gpcas_isa
 //
 // Copyright (c) 2021 Kai Rese
@@ -31,6 +31,6 @@ mod instruction;
 mod isa;
 
 pub use elf::{check_isa, ELFFileHeaderFront};
-pub use emulator::{format_c_string, Emulator, OperandStorage};
+pub use emulator::{format_c_string, Emulator, InteractiveEmulator, OperandStorage};
 pub use instruction::{instruction_flags, Instruction, IS_VECTOR_REGISTER, MAX_INPUTS};
 pub use isa::{Isa, IsaIdentifier, MemoryAccessType};
